import numpy as np
import math
import pandas
import os
from pyitlib import discrete_random_variable as drv
from itertools import groupby
from funcy import group_by

pandas.options.mode.chained_assignment = None 

if not os.path.exists('results_overall'):
    os.makedirs('results_overall')

inputfile = input("The csv file: ")

odf = pandas.read_csv(inputfile)

#Detect the codas

codas = ["v","d","l","n","r","m","ɣ","z","ʁ","ŋ"]
vbcod=[]
for syl in odf['verb']:
    thecoda = syl.strip()[-1]
    if  thecoda in codas:
        vbcod.append(thecoda)
    else:
        vbcod.append("nocoda")
odf['coda'] = vbcod

#Subset with only æ, ɑ, o as Stem 1 vowels

#df = odf.loc[odf['s1vowel'].isin(['æ','ɑ','o'])]

#Find patterns for v1 ~ v2

prepattern = odf[['s1vowel','s2vowel','nativeness','coda']]

prepatternfn = prepattern.drop_duplicates(subset=None)

v1v2 = prepattern[['s1vowel','s2vowel']]



#Predicting Stem 2


#Combine v1 v2

v1v2['v1v2'] = v1v2.s1vowel + v1v2.s2vowel

#Extract the column v1v2

v1v2 = v1v2[['v1v2']]

#to list the patterns

vlist = v1v2.v1v2.tolist()

#Remove duplicates
vlist2 = list(dict.fromkeys(vlist))

#Grouping the patterns and keep the values
vlistgrouped = group_by(0,vlist2).values()

#Add corresponding patterns to a list
vpatterns = []
for v in vlist:
    for p in vlistgrouped:
        if v in p:
            p=''.join(p)
            vpatterns.append(p)

#Add the patterns to csv
v1v2['v1v1v2']=vpatterns

#Remove duplicates and get the csv for computing
v1v2fn = v1v2.drop_duplicates(subset=None)


#Find patterns for n ~  v2

nv2 = prepattern[['nativeness','s2vowel']]

#Combine n v2
nv2['nv2'] = nv2.nativeness + nv2.s2vowel

#Extract the colunn nv2
nv2 = nv2[['nv2']]

#to list the patterns
nlist = nv2.nv2.tolist()

#Remove duplicates
nlist2 = list(dict.fromkeys(nlist))

#Grouping the patterns and keep the values
nlistgrouped = group_by(0,nlist2).values()

#Add corresponding patterns to a list
npatterns = []
for n in nlist:
    for p in nlistgrouped:
        if n in p:
            p=''.join(p)
            npatterns.append(p)

#Add the patterns to csv
nv2['nnv2'] = npatterns

#Remove duplicates and get the csv for computing
nv2fn = nv2.drop_duplicates(subset=None)





#Find patterns for c ~  v2

cv2 = prepattern[['coda','s2vowel']]

#Combine c v2
cv2['cv2'] = cv2.coda + cv2.s2vowel

#Extract the colunn cv2
cv2 = cv2[['cv2']]

#to list the patterns
clist = cv2.cv2.tolist()

#Remove duplicates
clist2 = list(dict.fromkeys(clist))

#Grouping the patterns and keep the values
clistgrouped = group_by(0,clist2).values()

#Add corresponding patterns to a list
cpatterns = []
for c in clist:
    for p in clistgrouped:
        if c in p:
            p=''.join(p)
            cpatterns.append(p)

#Add the patterns to csv
cv2['ccv2'] = cpatterns

#Remove duplicates and get the csv for computing
cv2fn = cv2.drop_duplicates(subset=None)






#Get v1 ~ nativeness
v1n =  prepattern[['s1vowel','nativeness']]
v1n['v1n'] = v1n.s1vowel + v1n.nativeness
v1n = v1n[['v1n']]

#Get v1 ~ coda
v1c =  prepattern[['s1vowel','coda']]
v1c['v1c'] = v1c.s1vowel + v1c.coda
v1c = v1c[['v1c']]

#Get nativeness ~ coda
nc =  prepattern[['nativeness','coda']]
nc['nc'] = nc.nativeness + nc.coda
nc = nc[['nc']]




#Combine all patterns
allpatterns = pandas.concat([v1v2, nv2, cv2,v1n,v1c,nc], axis=1, join='inner')

#Remove duplicates
allpatternsfn = allpatterns.drop_duplicates(subset=None)




#compute v1 ~ v2 entropy
prev1v2entropy = drv.entropy_conditional(v1v2.T)

v1v2entropy = prev1v2entropy[0,1]

#compute n ~ v2 entropy
#prenv2entropy = drv.entropy_conditional(nv2fn.T)

#nv2entropy = prenv2entropy[0,1]

#compute c ~ v2 entropy
#precv2entropy = drv.entropy_conditional(cv2fn.T)

#cv2entropy = precv2entropy[0,1]


#compute H(v1, coda => v2)
v1codv2 = allpatterns[['v1v2','cv2','v1v1v2','ccv2','v1c']]
v1codv2fn = v1codv2.drop_duplicates(subset=None)
v1codv2b = v1codv2[['v1v1v2','ccv2','v1c']]
v1codv2ent1 = drv.entropy_joint(v1codv2.T)
v1codv2ent2 = drv.entropy_joint(v1codv2b.T)
hv1codv2 = v1codv2ent1 - v1codv2ent2 


#compute H(v1, nativeness => v2)
v1nv2 = allpatterns[['v1v2','nv2','v1v1v2','nnv2','v1n']]
v1nv2fn = v1nv2.drop_duplicates(subset=None)
v1nv2b = v1nv2[['v1v1v2','nnv2','v1n']]
v1nv2ent1 = drv.entropy_joint(v1nv2.T)
v1nv2ent2 = drv.entropy_joint(v1nv2b.T)
hv1nv2 = v1nv2ent1 - v1nv2ent2 


#compute H(v1, coda, nativeness => v2)
allpatternsb = allpatterns[['v1v1v2','nnv2','ccv2','v1c','v1n','nc']]
allent1 = drv.entropy_joint(allpatterns.T)
allent2 = drv.entropy_joint(allpatternsb.T)
allent = allent1 - allent2 








#Predicting Stem 1
#mdf = odf.loc[odf['s2vowel'].isin(['i','u','ə','o'])]

prepattern2 =  odf[['s1vowel','s2vowel','nativeness','coda']]


prepattern2.drop_duplicates(subset=None, inplace=True)

v2v1 = prepattern2[['s2vowel','s1vowel']]

#Combine v1 v2

v2v1['v2v1'] = v2v1.s2vowel + v2v1.s1vowel

v2v1 = v2v1[['v2v1']]

volist = v2v1.v2v1.tolist()

#Remove duplicates
volist2 = list(dict.fromkeys(volist))

#Grouping the patterns and keep the values
volistgrouped = group_by(0,volist2).values()

#Add corresponding patterns to a list
vopatterns = []
for vo in volist:
    for p in volistgrouped:
        if vo in p:
            p=''.join(p)
            vopatterns.append(p)

#Add the patterns to csv
v2v1['v2v2v1']=vopatterns

#Remove duplicates and get the csv for computing
v2v1fn = v2v1.drop_duplicates(subset=None)



#Find patterns for n ~  v1

nv1 = prepattern2[['nativeness','s1vowel']]

#Combine n v1
nv1['nv1'] = nv1.nativeness + nv1.s1vowel

#Extract the colunn nv1
nv1 = nv1[['nv1']]

#to list the patterns
nalist = nv1.nv1.tolist()

#Remove duplicates
nalist2 = list(dict.fromkeys(nalist))

#Grouping the patterns and keep the values
nalistgrouped = group_by(0,nalist2).values()

#Add corresponding patterns to a list
napatterns = []
for na in nalist:
    for p in nalistgrouped:
        if na in p:
            p=''.join(p)
            napatterns.append(p)

#Add the patterns to csv
nv1['nnv1'] = napatterns

#Remove duplicates and get the csv for computing
nv1fn = nv1.drop_duplicates(subset=None)



#Find patterns for c ~  v1

cv1 = prepattern2[['coda','s1vowel']]

#Combine c v2
cv1['cv1'] = cv1.coda + cv1.s1vowel

#Extract the colunn cv2
cv1 = cv1[['cv1']]

#to list the patterns
colist = cv1.cv1.tolist()

#Remove duplicates
colist2 = list(dict.fromkeys(colist))

#Grouping the patterns and keep the values
colistgrouped = group_by(0,colist2).values()

#Add corresponding patterns to a list
copatterns = []
for co in colist:
    for p in colistgrouped:
        if co in p:
            p=''.join(p)
            copatterns.append(p)

#Add the patterns to csv
cv1['ccv1'] = copatterns

#Remove duplicates and get the csv for computing
cv1fn = cv1.drop_duplicates(subset=None)





#Get v2 ~ nativeness
v2n =  prepattern2[['s2vowel','nativeness']]
v2n['v2n'] = v2n.s2vowel + v2n.nativeness
v2n = v2n[['v2n']]

#Get v2 ~ coda
v2c =  prepattern2[['s2vowel','coda']]
v2c['v2c'] = v2c.s2vowel + v2c.coda
v2c = v2c[['v2c']]

#Get nativeness ~ coda
nc2 =  prepattern2[['nativeness','coda']]
nc2['nc'] = nc2.nativeness + nc2.coda
nc2 = nc2[['nc']]


#Combine all patterns
allpatterns2 = pandas.concat([v2v1, nv1, cv1,v2n,v2c,nc2], axis=1, join='inner')

#Remove duplicates
allpatterns2fn = allpatterns2.drop_duplicates(subset=None)






#compute v2 ~ v1 entropy
prev2v1entropy = drv.entropy_conditional(v2v1.T)

v2v1entropy = prev2v1entropy[0,1]


#compute n ~ v1 entropy
#prenv1entropy = drv.entropy_conditional(nv1fn.T)

#nv1entropy = prenv1entropy[0,1]


#compute c ~ v1 entropy
#precv1entropy = drv.entropy_conditional(cv1fn.T)

#cv1entropy = precv1entropy[0,1]


#compute H(v1, coda => v2)
v2codv1 = allpatterns2[['v2v1','cv1','v2v2v1','ccv1','v2c']]
v2codv1fn = v2codv1.drop_duplicates(subset=None)
v2codv1b = v2codv1[['v2v2v1','ccv1','v2c']]
v2codv1ent1 = drv.entropy_joint(v2codv1.T)
v2codv1ent2 = drv.entropy_joint(v2codv1b.T)
hv2codv1 = v2codv1ent1 - v2codv1ent2 


#compute H(v1, nativeness => v2)
v2nv1 = allpatterns2[['v2v1','nv1','v2v2v1','nnv1','v2n']]
v2nv1fn = v2nv1.drop_duplicates(subset=None)
v2nv1b = v2nv1[['v2v2v1','nnv1','v2n']]
v2nv1ent1 = drv.entropy_joint(v2nv1.T)
v2nv1ent2 = drv.entropy_joint(v2nv1b.T)
hv2nv1 = v2nv1ent1 - v2nv1ent2 


#compute H(v1, coda, nativeness => v2)
allpatterns2b = allpatterns2[['v2v2v1','nnv1','ccv1','v2c','v2n','nc']]
allent21 = drv.entropy_joint(allpatterns2.T)
allent22 = drv.entropy_joint(allpatterns2b.T)
allent2 = allent21 - allent22












#Output file

if inputfile == "allverbs.csv":
    with open('results_overall/entropies_allverbs.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(V1 => V2): ",v1v2entropy,'\n','\n',"H(V1, coda => V2): ",hv1codv2,'\n','\n',"H(V1, nativeness => V2): ",hv1nv2,'\n','\n',"H(V1,coda,nativeness => V2): ",allent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(V2 => V1): ",v2v1entropy,'\n','\n',"H(V2, coda => V1): ",hv2codv1,'\n','\n',"H(V2, nativeness => V1): ",hv2nv1,'\n','\n',"H(V2,coda,nativeness => V1): ",allent2,file=f)

if inputfile == "ablauting.csv":
    with open('results_overall/entropies_ablauting.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(V1 => V2): ",v1v2entropy,'\n','\n',"H(V1, coda => V2): ",hv1codv2,'\n','\n',"H(V1, nativeness => V2): ",hv1nv2,'\n','\n',"H(V1,coda,nativeness => V2): ",allent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(V2 => V1): ",v2v1entropy,'\n','\n',"H(V2, coda => V1): ",hv2codv1,'\n','\n',"H(V2, nativeness => V1): ",hv2nv1,'\n','\n',"H(V2,coda,nativeness => V1): ",allent2,file=f)

if inputfile == "allproto.csv":
    with open('results_overall/entropies_all_proto_verbs.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(V1 => V2): ",v1v2entropy,'\n','\n',"H(V1, coda => V2): ",hv1codv2,'\n','\n',"H(V1, nativeness => V2): ",hv1nv2,'\n','\n',"H(V1,coda,nativeness => V2): ",allent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(V2 => V1): ",v2v1entropy,'\n','\n',"H(V2, coda => V1): ",hv2codv1,'\n','\n',"H(V2, nativeness => V1): ",hv2nv1,'\n','\n',"H(V2,coda,nativeness => V1): ",allent2,file=f)

if inputfile == "ablautproto.csv":
    with open('results_overall/entropies_proto_ablauting.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(V1 => V2): ",v1v2entropy,'\n','\n',"H(V1, coda => V2): ",hv1codv2,'\n','\n',"H(V1, nativeness => V2): ",hv1nv2,'\n','\n',"H(V1,coda,nativeness => V2): ",allent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(V2 => V1): ",v2v1entropy,'\n','\n',"H(V2, coda => V1): ",hv2codv1,'\n','\n',"H(V2, nativeness => V1): ",hv2nv1,'\n','\n',"H(V2,coda,nativeness => V1): ",allent2,file=f)
