import matplotlib.pyplot as plt
import pandas
import os
import numpy as np
import ent
import bo

if not os.path.exists('results_overall'):
    os.makedirs('results_overall')

if ent.inputfile == "allverbs.csv":
    prev1 = "charts_allverbs/preV1_allverbs"
    prev2 = "charts_allverbs/preV2_allverbs"
    nd1v1 = "charts_allverbs/nd1v1_allverbs"
    nd2v1cod = "charts_allverbs/nd2v1cod_allverbs"
    nd2v1n = "charts_allverbs/nd2v1n_allverbs"
    nd3v1 = "charts_allverbs/nd3v1_allverbs"
    nd1v2 = "charts_allverbs/nd1v2_allverbs"
    nd2v2cod = "charts_allverbs/nd2v2cod_allverbs"
    nd2v2n = "charts_allverbs/nd2v2n_allverbs"
    nd3v2 = "charts_allverbs/nd3v2_allverbs"
    pre3 = "charts_allverbs/pre_allverbs"
    if not os.path.exists('results_overall/charts_allverbs'):
        os.makedirs('results_overall/charts_allverbs')


if ent.inputfile == "ablauting.csv":
    prev1 = "charts_ablauting/preV1_ablauting"
    prev2 = "charts_ablauting/preV2_ablauting"
    nd1v1 = "charts_ablauting/nd1v1_ablauting"
    nd2v1cod = "charts_ablauting/nd2v1cod_ablauting"
    nd2v1n = "charts_ablauting/nd2v1n_ablauting"
    nd3v1 = "charts_ablauting/nd3v1_ablauting"
    nd1v2 = "charts_ablauting/nd1v2_ablauting"
    nd2v2cod = "charts_ablauting/nd2v2cod_ablauting"
    nd2v2n = "charts_ablauting/nd2v2n_ablauting"
    nd3v2 = "charts_ablauting/nd3v2_ablauting"
    pre3 = "charts_ablauting/pre3_ablauting"
    if not os.path.exists('results_overall/charts_ablauting'):
        os.makedirs('results_overall/charts_ablauting')


#Prediction of V2

labels = ['1 (V1)', '2 (V1,coda)', '2 (V1, nat)', '3']

d1 = [ent.v1v2entropy,ent.hv1codv2,ent.hv1nv2,ent.allent]

d2 = [bo.mean1,bo.mean2,bo.mean3,bo.mean4]


x = np.arange(len(labels))  
width = 0.35  

fig, ax = plt.subplots(figsize=(13,10))
ax.bar(x - width/2, d1, width, label='actual', color='dimgray')
ax.bar(x + width/2, d2, width, label='bootstrap', color='darkgray')

ax.set_ylabel('Entropy values')
ax.set_xlabel('Predictors')

ax.set_xticks(x)
ax.set_xticklabels(labels)
ax.legend()
path1=os.path.join('results_overall',prev2)
plt.savefig(path1,bbox_inches='tight',pad_inches=0.1)


#Prediction of V1

label2 = ['1 (V2)','2 (V2,coda)', '2 (V2, nat)', '3',]

d3 = [ent.v2v1entropy,ent.hv2codv1,ent.hv2nv1,ent.allent2]

d4 = [bo.mean5,bo.mean6,bo.mean7,bo.mean8]


x2 = np.arange(len(label2))  
width = 0.35  

fig, ax = plt.subplots(figsize=(13,10))
ax.bar(x2 - width/2, d3, width, label='actual', color='dimgray')
ax.bar(x2 + width/2, d4, width, label='bootstrap', color='darkgray')

ax.set_ylabel('Entropy values')
ax.set_xlabel('Predictors')

ax.set_xticks(x2)
ax.set_xticklabels(label2)
ax.legend()
path2=os.path.join('results_overall',prev1)
plt.savefig(path2,bbox_inches='tight',pad_inches=0.1)




# 3-predictor barcharts

label3 = ['V1, coda, nativeness => V2','V2, coda, nativeness => V1']

d5 = [ent.allent,ent.allent2]

d6 = [bo.mean4,bo.mean8]


x2 = np.arange(len(label3))  
width = 0.35  

fig, ax = plt.subplots(figsize=(13,10))
ax.bar(x2 - width/2, d5, width, label='actual', color='dimgray')
ax.bar(x2 + width/2, d6, width, label='bootstrap', color='darkgray')

ax.set_ylabel('Entropy values')
ax.set_xlabel('Predictions')

ax.set_xticks(x2)
ax.set_xticklabels(label3)
ax.legend()
path3=os.path.join('results_overall',pre3)
plt.savefig(path3,bbox_inches='tight',pad_inches=0.1)



# Histograms

hist1 = bo.nd1v1.hist(bins=8, color = 'dimgray')
plt.axvline(x=ent.v1v2entropy,linestyle='dashed',color = 'dimgray')
path4=os.path.join('results_overall',nd1v1)
plt.savefig(path4,bbox_inches='tight',pad_inches=0.1)

hist2 = bo.nd2v1cod.hist(bins=10, color = 'dimgray')
plt.axvline(x=ent.hv1codv2,linestyle='dashed',color = 'dimgray')
path5=os.path.join('results_overall',nd2v1cod)
plt.savefig(path5,bbox_inches='tight',pad_inches=0.1)

hist3 = bo.nd2v1n.hist(bins=8,  color = 'dimgray')
plt.axvline(x=ent.hv1nv2,linestyle='dashed',color = 'dimgray')
path6=os.path.join('results_overall',nd2v1n)
plt.savefig(path6,bbox_inches='tight',pad_inches=0.1)

hist4 = bo.nd3v1.hist(bins=12,  color = 'dimgray')
plt.axvline(x=ent.allent,linestyle='dashed',color = 'dimgray')
path7=os.path.join('results_overall',nd3v1)
plt.savefig(path7,bbox_inches='tight',pad_inches=0.1)

hist5 = bo.nd1v2.hist(bins=8,  color = 'dimgray')
plt.axvline(x=ent.v2v1entropy,linestyle='dashed',color = 'dimgray')
path8=os.path.join('results_overall',nd1v2)
plt.savefig(path8,bbox_inches='tight',pad_inches=0.1)

hist6 = bo.nd2v2cod.hist(bins=8, color = 'dimgray')
plt.axvline(x=ent.hv2codv1,linestyle='dashed',color = 'dimgray')
path9=os.path.join('results_overall',nd2v2cod)
plt.savefig(path9,bbox_inches='tight',pad_inches=0.1)

hist7 = bo.nd2v2n.hist(bins=6,  color = 'dimgray')
plt.axvline(x=ent.hv2nv1,linestyle='dashed',color = 'dimgray')
path10=os.path.join('results_overall',nd2v2n)
plt.savefig(path10,bbox_inches='tight',pad_inches=0.1)

hist8 = bo.nd3v2.hist(bins=10,color = 'dimgray')
plt.axvline(x=ent.allent2,linestyle='dashed',color = 'dimgray')
path11=os.path.join('results_overall',nd3v2)
plt.savefig(path11,bbox_inches='tight',pad_inches=0.1)
