import matplotlib.pyplot as plt
import pandas
import os
import vow
import bov
import numpy as np

if not os.path.exists('results_vowels'):
    os.makedirs('results_vowels')

if vow.inputfile == "allverbs.csv":
    preV2vowel = "charts_allverbs/preV2vowel_allverbs"
    preV1vowel = "charts_allverbs/preV1_allverbs"
    s1ae = "charts_allverbs/s1ae_allverbs"
    s1a = "charts_allverbs/s1a_allverbs"
    s1o = "charts_allverbs/s1o_allverbs"
    s2i = "charts_allverbs/s2i_allverbs"
    s2e = "charts_allverbs/s2e_allverbs"
    s2u = "charts_allverbs/s2u_allverbs"
    s2o = "charts_allverbs/s2o_allverbs"
    if not os.path.exists('results_vowels/charts_allverbs'):
        os.makedirs('results_vowels/charts_allverbs')


if vow.inputfile == "ablauting.csv":
    preV2vowel = "charts_ablauting/preV2vowel_ablauting"
    preV1vowel = "charts_ablauting/preV1vowel_ablauting"
    s1ae = "charts_ablauting/s1ae_ablauting"
    s1a = "charts_ablauting/s1a_ablauting"
    s1o = "charts_ablauting/s1o_ablauting"
    s2i = "charts_ablauting/s2i_ablauting"
    s2e = "charts_ablauting/s2e_ablauting"
    s2u = "charts_ablauting/s2u_ablauting"
    s2o = "charts_ablauting/s2o_ablauting"
    if not os.path.exists('results_vowels/charts_ablauting'):
        os.makedirs('results_vowels/charts_ablauting')


#Prediction of V2

labels = ['s1:æ', 's1:ɑ', 's1:o']

d1 = [vow.aeent,vow.aaent,vow.ooent]

d2 = [bov.mean1,bov.mean2,bov.mean3]


x = np.arange(len(labels))  
width = 0.35  

fig, ax = plt.subplots(figsize=(13,10))
ax.bar(x - width/2, d1, width, label='actual', color='dimgray')
ax.bar(x + width/2, d2, width, label='bootstrap', color='darkgray')

ax.set_ylabel('Entropy values')
ax.set_xlabel('Predictors')

ax.set_xticks(x)
ax.set_xticklabels(labels)
ax.legend()
path1=os.path.join('results_vowels',preV2vowel)
plt.savefig(path1,bbox_inches='tight',pad_inches=0.1)


#Prediction of V1

label2 = ['s2:i','s2:ə', 's2:u', 's2:o']

d3 = [vow.ijient,vow.ejeent,vow.ujuent,vow.ojoent]

d4 = [bov.mean4,bov.mean5,bov.mean6,bov.mean7]


x2 = np.arange(len(label2))  
width = 0.35  

fig, ax = plt.subplots(figsize=(13,10))
ax.bar(x2 - width/2, d3, width, label='actual', color='dimgray')
ax.bar(x2 + width/2, d4, width, label='bootstrap', color='darkgray')

ax.set_ylabel('Entropy values')
ax.set_xlabel('Predictors')

ax.set_xticks(x2)
ax.set_xticklabels(label2)
ax.legend()
path2=os.path.join('results_vowels',preV1vowel)
plt.savefig(path2,bbox_inches='tight',pad_inches=0.1)


# Histograms

hist1 = bov.s1ae.hist(bins=15, color = 'dimgray')
plt.axvline(x=vow.aeent,linestyle='dashed',color = 'dimgray')
path3=os.path.join('results_vowels',s1ae)
plt.savefig(path3,bbox_inches='tight',pad_inches=0.1)

hist2 = bov.s1a.hist(bins=5,  color = 'dimgray')
plt.axvline(x=vow.aaent,linestyle='dashed',color = 'dimgray')
path4=os.path.join('results_vowels',s1a)
plt.savefig(path4,bbox_inches='tight',pad_inches=0.1)

hist3 = bov.s1o.hist(bins=8,  color = 'dimgray')
plt.axvline(x=vow.ooent,linestyle='dashed',color = 'dimgray')
path5=os.path.join('results_vowels',s1o)
plt.savefig(path5,bbox_inches='tight',pad_inches=0.1)

hist4 = bov.s2i.hist(bins=8,  color = 'dimgray')
plt.axvline(x=vow.ijient,linestyle='dashed',color = 'dimgray')
path6=os.path.join('results_vowels',s2i)
plt.savefig(path6,bbox_inches='tight',pad_inches=0.1)

hist5 = bov.s2e.hist(bins=8,  color = 'dimgray')
plt.axvline(x=vow.ejeent,linestyle='dashed',color = 'dimgray')
path7=os.path.join('results_vowels',s2e)
plt.savefig(path7,bbox_inches='tight',pad_inches=0.1)

hist6 = bov.s2u.hist(bins=8, color = 'dimgray')
plt.axvline(x=vow.ujuent,linestyle='dashed',color = 'dimgray')
path8=os.path.join('results_vowels',s2u)
plt.savefig(path8,bbox_inches='tight',pad_inches=0.1)

hist7 = bov.s2o.hist(bins=5,  color = 'dimgray')
plt.axvline(x=vow.ojoent,linestyle='dashed',color = 'dimgray')
path9=os.path.join('results_vowels',s2o)
plt.savefig(path9,bbox_inches='tight',pad_inches=0.1)
