import numpy as np
import math
import pandas
import os
from pyitlib import discrete_random_variable as drv
from itertools import groupby
from funcy import group_by

pandas.options.mode.chained_assignment = None 

if not os.path.exists('results_vowels'):
    os.makedirs('results_vowels')


inputfile = input("The csv file: ")

odf = pandas.read_csv(inputfile)

#Detect the codas

codas = ["v","d","l","n","r","m","ɣ","z","ʁ","ŋ"]
vbcod=[]
for syl in odf['verb']:
    thecoda = syl.strip()[-1]
    if  thecoda in codas:
        vbcod.append(thecoda)
    else:
        vbcod.append("nocoda")
odf['coda'] = vbcod


### Dealing with æ ###

#Subset 

aedf = odf.loc[odf['s1vowel'].isin(['æ'])]

#Find patterns for v1 ~ v2

aepre = aedf[['s1vowel','s2vowel','nativeness','coda']]

aeprefn =  aepre.drop_duplicates(subset=None)

ae12 = aepre[['s1vowel','s2vowel']]



#Predicting Stem 2


#Combine v1 v2

ae12['v1v2'] = ae12.s1vowel + ae12.s2vowel

#Extract the column v1v2

ae12 = ae12[['v1v2']]

#to list the patterns

aevlist = ae12.v1v2.tolist()

#Remove duplicates
aevlist2 = list(dict.fromkeys(aevlist))

#Grouping the patterns and keep the values
aevgrp = group_by(0,aevlist2).values()

#Add corresponding patterns to a list
aevpat = []
for v in aevlist:
    for p in aevgrp:
        if v in p:
            p=''.join(p)
            aevpat.append(p)

#Add the patterns to csv
ae12['v1v1v2']=aevpat

#Remove duplicates and get the csv for computing
ae12fn = ae12.drop_duplicates(subset=None)




#Find patterns for n ~  v2

aenv2 = aepre[['nativeness','s2vowel']]

#Combine n v2
aenv2['nv2'] = aenv2.nativeness + aenv2.s2vowel

#Extract the colunn nv2
aenv2 = aenv2[['nv2']]

#to list the patterns
aenlist = aenv2.nv2.tolist()

#Remove duplicates
aenlist2 = list(dict.fromkeys(aenlist))

#Grouping the patterns and keep the values
aengrp = group_by(0,aenlist2).values()

#Add corresponding patterns to a list
aenpat = []
for n in aenlist:
    for p in aengrp:
        if n in p:
            p=''.join(p)
            aenpat.append(p)

#Add the patterns to csv
aenv2['nnv2'] = aenpat

#Remove duplicates and get the csv for computing
aenv2fn = aenv2.drop_duplicates(subset=None)





#Find patterns for c ~  v2

aecv2 = aepre[['coda','s2vowel']]

#Combine c v2
aecv2['cv2'] = aecv2.coda + aecv2.s2vowel

#Extract the colunn cv2
aecv2 = aecv2[['cv2']]

#to list the patterns
aeclist = aecv2.cv2.tolist()

#Remove duplicates
aeclist2 = list(dict.fromkeys(aeclist))

#Grouping the patterns and keep the values
aecgrp = group_by(0,aeclist2).values()

#Add corresponding patterns to a list
aecpat = []
for c in aeclist:
    for p in aecgrp:
        if c in p:
            p=''.join(p)
            aecpat.append(p)

#Add the patterns to csv
aecv2['ccv2'] = aecpat

#Remove duplicates and get the csv for computing
aecv2fn = aecv2.drop_duplicates(subset=None)






#Get v1 ~ nativeness
aev1n =  aepre[['s1vowel','nativeness']]
aev1n['v1n'] = aev1n.s1vowel + aev1n.nativeness
aev1n = aev1n[['v1n']]

#Get v1 ~ coda
aev1c =  aepre[['s1vowel','coda']]
aev1c['v1c'] = aev1c.s1vowel + aev1c.coda
aev1c = aev1c[['v1c']]

#Get nativeness ~ coda
aenc =  aepre[['nativeness','coda']]
aenc['nc'] = aenc.nativeness + aenc.coda
aenc = aenc[['nc']]




#Combine all patterns
aeall = pandas.concat([ae12, aenv2, aecv2,aev1n,aev1c,aenc], axis=1, join='inner')

#Remove duplicates
aeallfn = aeall.drop_duplicates(subset=None)



#compute H(v1, coda, nativeness => v2)
aeallb = aeall[['v1v1v2','nnv2','ccv2','v1c','v1n','nc']]
aeent1 = drv.entropy_joint(aeall.T)
aeent2 = drv.entropy_joint(aeallb.T)
aeent = aeent1 - aeent2 






### Dealing with ɑ ###

aadf = odf.loc[odf['s1vowel'].isin(['ɑ'])]

#Find patterns for v1 ~ v2

aapre = aadf[['s1vowel','s2vowel','nativeness','coda']]

aaprefn = aapre.drop_duplicates(subset=None)

aa12 = aapre[['s1vowel','s2vowel']]



#Predicting Stem 2


#Combine v1 v2

aa12['v1v2'] = aa12.s1vowel + aa12.s2vowel

#Extract the column v1v2

aa12 = aa12[['v1v2']]

#to list the patterns

aavlist = aa12.v1v2.tolist()

#Remove duplicates
aavlist2 = list(dict.fromkeys(aavlist))

#Grouping the patterns and keep the values
aavgrp = group_by(0,aavlist2).values()

#Add corresponding patterns to a list
aavpat = []
for v in aavlist:
    for p in aavgrp:
        if v in p:
            p=''.join(p)
            aavpat.append(p)

#Add the patterns to csv
aa12['v1v1v2']=aavpat

#Remove duplicates and get the csv for computing
aa12fn = aa12.drop_duplicates(subset=None)




#Find patterns for n ~  v2

aanv2 = aapre[['nativeness','s2vowel']]

#Combine n v2
aanv2['nv2'] = aanv2.nativeness + aanv2.s2vowel

#Extract the colunn nv2
aanv2 = aanv2[['nv2']]

#to list the patterns
aanlist = aanv2.nv2.tolist()

#Remove duplicates
aanlist2 = list(dict.fromkeys(aanlist))

#Grouping the patterns and keep the values
aangrp = group_by(0,aanlist2).values()

#Add corresponding patterns to a list
aanpat = []
for n in aanlist:
    for p in aangrp:
        if n in p:
            p=''.join(p)
            aanpat.append(p)

#Add the patterns to csv
aanv2['nnv2'] = aanpat

#Remove duplicates and get the csv for computing
aanv2fn = aanv2.drop_duplicates(subset=None)





#Find patterns for c ~  v2

aacv2 = aapre[['coda','s2vowel']]

#Combine c v2
aacv2['cv2'] = aacv2.coda + aacv2.s2vowel

#Extract the colunn cv2
aacv2 = aacv2[['cv2']]

#to list the patterns
aaclist = aacv2.cv2.tolist()

#Remove duplicates
aaclist2 = list(dict.fromkeys(aaclist))

#Grouping the patterns and keep the values
aacgrp = group_by(0,aaclist2).values()

#Add corresponding patterns to a list
aacpat = []
for c in aaclist:
    for p in aacgrp:
        if c in p:
            p=''.join(p)
            aacpat.append(p)

#Add the patterns to csv
aacv2['ccv2'] = aacpat

#Remove duplicates and get the csv for computing
aacv2fn = aacv2.drop_duplicates(subset=None)






#Get v1 ~ nativeness
aav1n =  aapre[['s1vowel','nativeness']]
aav1n['v1n'] = aav1n.s1vowel + aav1n.nativeness
aav1n = aav1n[['v1n']]

#Get v1 ~ coda
aav1c =  aapre[['s1vowel','coda']]
aav1c['v1c'] = aav1c.s1vowel + aav1c.coda
aav1c = aav1c[['v1c']]

#Get nativeness ~ coda
aanc =  aapre[['nativeness','coda']]
aanc['nc'] = aanc.nativeness + aanc.coda
aanc = aanc[['nc']]




#Combine all patterns
aaall = pandas.concat([aa12, aanv2, aacv2,aav1n,aav1c,aanc], axis=1, join='inner')

#Remove duplicates
aaallfn = aaall.drop_duplicates(subset=None)



#compute H(v1, coda, nativeness => v2)
aaallb = aaall[['v1v1v2','nnv2','ccv2','v1c','v1n','nc']]
aaent1 = drv.entropy_joint(aaall.T)
aaent2 = drv.entropy_joint(aaallb.T)
aaent = aaent1 - aaent2 







### Dealing with o ###

oodf = odf.loc[odf['s1vowel'].isin(['o'])]

#Find patterns for v1 ~ v2

oopre = oodf[['s1vowel','s2vowel','nativeness','coda']]

ooprefn = oopre.drop_duplicates(subset=None)

oo12 = oopre[['s1vowel','s2vowel']]



#Predicting Stem 2


#Combine v1 v2

oo12['v1v2'] = oo12.s1vowel + oo12.s2vowel

#Extract the column v1v2

oo12 = oo12[['v1v2']]

#to list the patterns

oovlist = oo12.v1v2.tolist()

#Remove duplicates
oovlist2 = list(dict.fromkeys(oovlist))

#Grouping the patterns and keep the values
oovgrp = group_by(0,oovlist2).values()

#Add corresponding patterns to a list
oovpat = []
for v in oovlist:
    for p in oovgrp:
        if v in p:
            p=''.join(p)
            oovpat.append(p)

#Add the patterns to csv
oo12['v1v1v2']=oovpat

#Remove duplicates and get the csv for computing
oo12fn = oo12.drop_duplicates(subset=None)




#Find patterns for n ~  v2

oonv2 = oopre[['nativeness','s2vowel']]

#Combine n v2
oonv2['nv2'] = oonv2.nativeness + oonv2.s2vowel

#Extract the colunn nv2
oonv2 = oonv2[['nv2']]

#to list the patterns
oonlist = oonv2.nv2.tolist()

#Remove duplicates
oonlist2 = list(dict.fromkeys(oonlist))

#Grouping the patterns and keep the values
oongrp = group_by(0,oonlist2).values()

#Add corresponding patterns to a list
oonpat = []
for n in oonlist:
    for p in oongrp:
        if n in p:
            p=''.join(p)
            oonpat.append(p)

#Add the patterns to csv
oonv2['nnv2'] = oonpat

#Remove duplicates and get the csv for computing
oonv2fn = oonv2.drop_duplicates(subset=None)





#Find patterns for c ~  v2

oocv2 = oopre[['coda','s2vowel']]

#Combine c v2
oocv2['cv2'] = oocv2.coda + oocv2.s2vowel

#Extract the colunn cv2
oocv2 = oocv2[['cv2']]

#to list the patterns
ooclist = oocv2.cv2.tolist()

#Remove duplicates
ooclist2 = list(dict.fromkeys(ooclist))

#Grouping the patterns and keep the values
oocgrp = group_by(0,ooclist2).values()

#Add corresponding patterns to a list
oocpat = []
for c in ooclist:
    for p in oocgrp:
        if c in p:
            p=''.join(p)
            oocpat.append(p)

#Add the patterns to csv
oocv2['ccv2'] = oocpat

#Remove duplicates and get the csv for computing
oocv2fn = oocv2.drop_duplicates(subset=None)






#Get v1 ~ nativeness
oov1n =  oopre[['s1vowel','nativeness']]
oov1n['v1n'] = oov1n.s1vowel + oov1n.nativeness
oov1n = oov1n[['v1n']]

#Get v1 ~ coda
oov1c =  oopre[['s1vowel','coda']]
oov1c['v1c'] = oov1c.s1vowel + oov1c.coda
oov1c = oov1c[['v1c']]

#Get nativeness ~ coda
oonc =  oopre[['nativeness','coda']]
oonc['nc'] = oonc.nativeness + oonc.coda
oonc = oonc[['nc']]




#Combine all patterns
ooall = pandas.concat([oo12, oonv2, oocv2,oov1n,oov1c,oonc], axis=1, join='inner')

#Remove duplicates
ooallfn = ooall.drop_duplicates(subset=None)



#compute H(v1, coda, nativeness => v2)
ooallb = ooall[['v1v1v2','nnv2','ccv2','v1c','v1n','nc']]
ooent1 = drv.entropy_joint(ooall.T)
ooent2 = drv.entropy_joint(ooallb.T)
ooent = ooent1 - ooent2 













###### Predicting Stem 1 ######

ijidf = odf.loc[odf['s2vowel'].isin(['i'])]

#Find patterns for v2 ~ v1

ijipre = ijidf[['s1vowel','s2vowel','nativeness','coda']]

ijiprefn = ijipre.drop_duplicates(subset=None)

iji21 = ijipre[['s1vowel','s2vowel']]



#Combine v2 v1

iji21['v2v1'] = iji21.s2vowel + iji21.s1vowel

#Extract the column v2v1

iji21 = iji21[['v2v1']]

#to list the patterns

ijivlist = iji21.v2v1.tolist()

#Remove duplicates
ijivlist2 = list(dict.fromkeys(ijivlist))

#Grouping the patterns and keep the values
ijivgrp = group_by(0,ijivlist2).values()

#Add corresponding patterns to a list
ijivpat = []
for v in ijivlist:
    for p in ijivgrp:
        if v in p:
            p=''.join(p)
            ijivpat.append(p)

#Add the patterns to csv
iji21['v2v2v1']=ijivpat

#Remove duplicates and get the csv for computing
iji21fn = iji21.drop_duplicates(subset=None)




#Find patterns for n ~  v2

ijinv1 = ijipre[['nativeness','s2vowel']]

#Combine n v2
ijinv1['nv1'] = ijinv1.nativeness + ijinv1.s2vowel

#Extract the colunn nv1
ijinv1 = ijinv1[['nv1']]

#to list the patterns
ijinlist = ijinv1.nv1.tolist()

#Remove duplicates
ijinlist2 = list(dict.fromkeys(ijinlist))

#Grouping the patterns and keep the values
ijingrp = group_by(0,ijinlist2).values()

#Add corresponding patterns to a list
ijinpat = []
for n in ijinlist:
    for p in ijingrp:
        if n in p:
            p=''.join(p)
            ijinpat.append(p)

#Add the patterns to csv
ijinv1['nnv1'] = ijinpat

#Remove duplicates and get the csv for computing
ijinv1fn = ijinv1.drop_duplicates(subset=None)





#Find patterns for c ~  v2

ijicv1 = ijipre[['coda','s2vowel']]

#Combine c v2
ijicv1['cv1'] = ijicv1.coda + ijicv1.s2vowel

#Extract the colunn cv1
ijicv1 = ijicv1[['cv1']]

#to list the patterns
ijiclist = ijicv1.cv1.tolist()

#Remove duplicates
ijiclist2 = list(dict.fromkeys(ijiclist))

#Grouping the patterns and keep the values
ijicgrp = group_by(0,ijiclist2).values()

#Add corresponding patterns to a list
ijicpat = []
for c in ijiclist:
    for p in ijicgrp:
        if c in p:
            p=''.join(p)
            ijicpat.append(p)

#Add the patterns to csv
ijicv1['ccv1'] = ijicpat

#Remove duplicates and get the csv for computing
ijicv1fn = ijicv1.drop_duplicates(subset=None)






#Get v2 ~ nativeness
ijiv2n =  ijipre[['s2vowel','nativeness']]
ijiv2n['v2n'] = ijiv2n.s2vowel + ijiv2n.nativeness
ijiv2n = ijiv2n[['v2n']]

#Get v2 ~ coda
ijiv2c =  ijipre[['s2vowel','coda']]
ijiv2c['v2c'] = ijiv2c.s2vowel + ijiv2c.coda
ijiv2c = ijiv2c[['v2c']]

#Get nativeness ~ coda
ijinc =  ijipre[['nativeness','coda']]
ijinc['nc'] = ijinc.nativeness + ijinc.coda
ijinc = ijinc[['nc']]




#Combine all patterns
ijiall = pandas.concat([iji21, ijinv1, ijicv1,ijiv2n,ijiv2c,ijinc], axis=1, join='inner')

#Remove duplicates
ijiallfn = ijiall.drop_duplicates(subset=None)


#compute H(v1, coda, nativeness => v2)
ijiallb = ijiall[['v2v2v1','nnv1','ccv1','v2c','v2n','nc']]
ijient1 = drv.entropy_joint(ijiall.T)
ijient2 = drv.entropy_joint(ijiallb.T)
ijient = ijient1 - ijient2 





#### Dealing with ə ####

ejedf = odf.loc[odf['s2vowel'].isin(['ə'])]

#Find patterns for v2 ~ v1

ejepre = ejedf[['s1vowel','s2vowel','nativeness','coda']]

ejeprefn = ejepre.drop_duplicates(subset=None)

eje21 = ejepre[['s1vowel','s2vowel']]



#Predicting Stem 1


#Combine v2 v1

eje21['v2v1'] = eje21.s2vowel + eje21.s1vowel

#Extract the column v2v1

eje21 = eje21[['v2v1']]

#to list the patterns

ejevlist = eje21.v2v1.tolist()

#Remove duplicates
ejevlist2 = list(dict.fromkeys(ejevlist))

#Grouping the patterns and keep the values
ejevgrp = group_by(0,ejevlist2).values()

#Add corresponding patterns to a list
ejevpat = []
for v in ejevlist:
    for p in ejevgrp:
        if v in p:
            p=''.join(p)
            ejevpat.append(p)

#Add the patterns to csv
eje21['v2v2v1']=ejevpat

#Remove duplicates and get the csv for computing
eje21fn = eje21.drop_duplicates(subset=None)




#Find patterns for n ~  v2

ejenv1 = ejepre[['nativeness','s2vowel']]

#Combine n v2
ejenv1['nv1'] = ejenv1.nativeness + ejenv1.s2vowel

#Extract the colunn nv1
ejenv1 = ejenv1[['nv1']]

#to list the patterns
ejenlist = ejenv1.nv1.tolist()

#Remove duplicates
ejenlist2 = list(dict.fromkeys(ejenlist))

#Grouping the patterns and keep the values
ejengrp = group_by(0,ejenlist2).values()

#Add corresponding patterns to a list
ejenpat = []
for n in ejenlist:
    for p in ejengrp:
        if n in p:
            p=''.join(p)
            ejenpat.append(p)

#Add the patterns to csv
ejenv1['nnv1'] = ejenpat

#Remove duplicates and get the csv for computing
ejenv1fn = ejenv1.drop_duplicates(subset=None)





#Find patterns for c ~  v2

ejecv1 = ejepre[['coda','s2vowel']]

#Combine c v2
ejecv1['cv1'] = ejecv1.coda + ejecv1.s2vowel

#Extract the colunn cv1
ejecv1 = ejecv1[['cv1']]

#to list the patterns
ejeclist = ejecv1.cv1.tolist()

#Remove duplicates
ejeclist2 = list(dict.fromkeys(ejeclist))

#Grouping the patterns and keep the values
ejecgrp = group_by(0,ejeclist2).values()

#Add corresponding patterns to a list
ejecpat = []
for c in ejeclist:
    for p in ejecgrp:
        if c in p:
            p=''.join(p)
            ejecpat.append(p)

#Add the patterns to csv
ejecv1['ccv1'] = ejecpat

#Remove duplicates and get the csv for computing
ejecv1fn = ejecv1.drop_duplicates(subset=None)






#Get v2 ~ nativeness
ejev2n =  ejepre[['s2vowel','nativeness']]
ejev2n['v2n'] = ejev2n.s2vowel + ejev2n.nativeness
ejev2n = ejev2n[['v2n']]

#Get v2 ~ coda
ejev2c =  ejepre[['s2vowel','coda']]
ejev2c['v2c'] = ejev2c.s2vowel + ejev2c.coda
ejev2c = ejev2c[['v2c']]

#Get nativeness ~ coda
ejenc =  ejepre[['nativeness','coda']]
ejenc['nc'] = ejenc.nativeness + ejenc.coda
ejenc = ejenc[['nc']]




#Combine all patterns
ejeall = pandas.concat([eje21, ejenv1, ejecv1,ejev2n,ejev2c,ejenc], axis=1, join='inner')

#Remove duplicates
ejeallfn = ejeall.drop_duplicates(subset=None)


#compute H(v1, coda, nativeness => v2)
ejeallb = ejeall[['v2v2v1','nnv1','ccv1','v2c','v2n','nc']]
ejeent1 = drv.entropy_joint(ejeall.T)
ejeent2 = drv.entropy_joint(ejeallb.T)
ejeent = ejeent1 - ejeent2 




#### Dealing with u ####

ujudf = odf.loc[odf['s2vowel'].isin(['u'])]

#Find patterns for v2 ~ v1

ujupre = ujudf[['s1vowel','s2vowel','nativeness','coda']]

ujuprefn = ujupre.drop_duplicates(subset=None)

uju21 = ujupre[['s1vowel','s2vowel']]



#Predicting Stem 1


#Combine v2 v1

uju21['v2v1'] = uju21.s2vowel + uju21.s1vowel

#Extract the column v2v1

uju21 = uju21[['v2v1']]

#to list the patterns

ujuvlist = uju21.v2v1.tolist()

#Remove duplicates
ujuvlist2 = list(dict.fromkeys(ujuvlist))

#Grouping the patterns and keep the values
ujuvgrp = group_by(0,ujuvlist2).values()

#Add corresponding patterns to a list
ujuvpat = []
for v in ujuvlist:
    for p in ujuvgrp:
        if v in p:
            p=''.join(p)
            ujuvpat.append(p)

#Add the patterns to csv
uju21['v2v2v1']=ujuvpat

#Remove duplicates and get the csv for computing
uju21fn = uju21.drop_duplicates(subset=None)




#Find patterns for n ~  v2

ujunv1 = ujupre[['nativeness','s2vowel']]

#Combine n v2
ujunv1['nv1'] = ujunv1.nativeness + ujunv1.s2vowel

#Extract the colunn nv1
ujunv1 = ujunv1[['nv1']]

#to list the patterns
ujunlist = ujunv1.nv1.tolist()

#Remove duplicates
ujunlist2 = list(dict.fromkeys(ujunlist))

#Grouping the patterns and keep the values
ujungrp = group_by(0,ujunlist2).values()

#Add corresponding patterns to a list
ujunpat = []
for n in ujunlist:
    for p in ujungrp:
        if n in p:
            p=''.join(p)
            ujunpat.append(p)

#Add the patterns to csv
ujunv1['nnv1'] = ujunpat

#Remove duplicates and get the csv for computing
ujunv1fn = ujunv1.drop_duplicates(subset=None)





#Find patterns for c ~  v2

ujucv1 = ujupre[['coda','s2vowel']]

#Combine c v2
ujucv1['cv1'] = ujucv1.coda + ujucv1.s2vowel

#Extract the colunn cv1
ujucv1 = ujucv1[['cv1']]

#to list the patterns
ujuclist = ujucv1.cv1.tolist()

#Remove duplicates
ujuclist2 = list(dict.fromkeys(ujuclist))

#Grouping the patterns and keep the values
ujucgrp = group_by(0,ujuclist2).values()

#Add corresponding patterns to a list
ujucpat = []
for c in ujuclist:
    for p in ujucgrp:
        if c in p:
            p=''.join(p)
            ujucpat.append(p)

#Add the patterns to csv
ujucv1['ccv1'] = ujucpat

#Remove duplicates and get the csv for computing
ujucv1fn = ujucv1.drop_duplicates(subset=None)






#Get v2 ~ nativeness
ujuv2n =  ujupre[['s2vowel','nativeness']]
ujuv2n['v2n'] = ujuv2n.s2vowel + ujuv2n.nativeness
ujuv2n = ujuv2n[['v2n']]

#Get v2 ~ coda
ujuv2c =  ujupre[['s2vowel','coda']]
ujuv2c['v2c'] = ujuv2c.s2vowel + ujuv2c.coda
ujuv2c = ujuv2c[['v2c']]

#Get nativeness ~ coda
ujunc =  ujupre[['nativeness','coda']]
ujunc['nc'] = ujunc.nativeness + ujunc.coda
ujunc = ujunc[['nc']]




#Combine all patterns
ujuall = pandas.concat([uju21, ujunv1, ujucv1,ujuv2n,ujuv2c,ujunc], axis=1, join='inner')

#Remove duplicates
ujuallfn = ujuall.drop_duplicates(subset=None)


#compute H(v1, coda, nativeness => v2)
ujuallb = ujuall[['v2v2v1','nnv1','ccv1','v2c','v2n','nc']]
ujuent1 = drv.entropy_joint(ujuall.T)
ujuent2 = drv.entropy_joint(ujuallb.T)
ujuent = ujuent1 - ujuent2 



#### Dealing with o ####


ojodf = odf.loc[odf['s2vowel'].isin(['o'])]

#Find patterns for v2 ~ v1

ojopre = ojodf[['s1vowel','s2vowel','nativeness','coda']]

ojoprefn = ojopre.drop_duplicates(subset=None)

ojo21 = ojopre[['s1vowel','s2vowel']]



#Predicting Stem 1


#Combine v2 v1

ojo21['v2v1'] = ojo21.s2vowel + ojo21.s1vowel

#Extract the column v2v1

ojo21 = ojo21[['v2v1']]

#to list the patterns

ojovlist = ojo21.v2v1.tolist()

#Remove duplicates
ojovlist2 = list(dict.fromkeys(ojovlist))

#Grouping the patterns and keep the values
ojovgrp = group_by(0,ojovlist2).values()

#Add corresponding patterns to a list
ojovpat = []
for v in ojovlist:
    for p in ojovgrp:
        if v in p:
            p=''.join(p)
            ojovpat.append(p)

#Add the patterns to csv
ojo21['v2v2v1']=ojovpat

#Remove duplicates and get the csv for computing
ojo21fn = ojo21.drop_duplicates(subset=None)




#Find patterns for n ~  v2

ojonv1 = ojopre[['nativeness','s2vowel']]

#Combine n v2
ojonv1['nv1'] = ojonv1.nativeness + ojonv1.s2vowel

#Extract the colunn nv1
ojonv1 = ojonv1[['nv1']]

#to list the patterns
ojonlist = ojonv1.nv1.tolist()

#Remove duplicates
ojonlist2 = list(dict.fromkeys(ojonlist))

#Grouping the patterns and keep the values
ojongrp = group_by(0,ojonlist2).values()

#Add corresponding patterns to a list
ojonpat = []
for n in ojonlist:
    for p in ojongrp:
        if n in p:
            p=''.join(p)
            ojonpat.append(p)

#Add the patterns to csv
ojonv1['nnv1'] = ojonpat

#Remove duplicates and get the csv for computing
ojonv1fn = ojonv1.drop_duplicates(subset=None)





#Find patterns for c ~  v2

ojocv1 = ojopre[['coda','s2vowel']]

#Combine c v2
ojocv1['cv1'] = ojocv1.coda + ojocv1.s2vowel

#Extract the colunn cv1
ojocv1 = ojocv1[['cv1']]

#to list the patterns
ojoclist = ojocv1.cv1.tolist()

#Remove duplicates
ojoclist2 = list(dict.fromkeys(ojoclist))

#Grouping the patterns and keep the values
ojocgrp = group_by(0,ojoclist2).values()

#Add corresponding patterns to a list
ojocpat = []
for c in ojoclist:
    for p in ojocgrp:
        if c in p:
            p=''.join(p)
            ojocpat.append(p)

#Add the patterns to csv
ojocv1['ccv1'] = ojocpat

#Remove duplicates and get the csv for computing
ojocv1fn = ojocv1.drop_duplicates(subset=None)






#Get v2 ~ nativeness
ojov2n =  ojopre[['s2vowel','nativeness']]
ojov2n['v2n'] = ojov2n.s2vowel + ojov2n.nativeness
ojov2n = ojov2n[['v2n']]

#Get v2 ~ coda
ojov2c =  ojopre[['s2vowel','coda']]
ojov2c['v2c'] = ojov2c.s2vowel + ojov2c.coda
ojov2c = ojov2c[['v2c']]

#Get nativeness ~ coda
ojonc =  ojopre[['nativeness','coda']]
ojonc['nc'] = ojonc.nativeness + ojonc.coda
ojonc = ojonc[['nc']]




#Combine all patterns
ojoall = pandas.concat([ojo21, ojonv1, ojocv1,ojov2n,ojov2c,ojonc], axis=1, join='inner')

#Remove duplicates
ojoallfn = ojoall.drop_duplicates(subset=None)


#compute H(v1, coda, nativeness => v2)
ojoallb = ojoall[['v2v2v1','nnv1','ccv1','v2c','v2n','nc']]
ojoent1 = drv.entropy_joint(ojoall.T)
ojoent2 = drv.entropy_joint(ojoallb.T)
ojoent = ojoent1 - ojoent2 






#Output file
if inputfile == "allverbs.csv":
    with open('results_vowels/vowel_entropies_allverbs.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(æ, coda, nativeness => V2): ",aeent,'\n','\n',"H(ɑ, coda, nativeness => V2): ",aaent,'\n','\n',"H(o, coda, nativeness => V2): ",ooent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(i, coda, nativeness => V1): ",ijient,'\n','\n',"H(ə, coda, nativeness => V1): ",ejeent,'\n','\n',"H(u, coda, nativeness => V1): ",ujuent,'\n','\n',"H(o,coda,nativeness => V1): ", ojoent, file=f)

if inputfile == "ablauting.csv":
    with open('results_vowels/vowel_entropies_ablauting.txt','w') as f:
        print("Predicting Stem 2"'\n','\n','\n',"H(æ, coda, nativeness => V2): ",aeent,'\n','\n',"H(ɑ, coda, nativeness => V2): ",aaent,'\n','\n',"H(o, coda, nativeness => V2): ",ooent,'\n','\n','\n','\n',"Predicting Stem 1"'\n','\n','\n',"H(i, coda, nativeness => V1): ",ijient,'\n','\n',"H(ə, coda, nativeness => V1): ",ejeent,'\n','\n',"H(u, coda, nativeness => V1): ",ujuent,'\n','\n',"H(o,coda,nativeness => V1): ", ojoent, file=f)


